/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2017 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.ui.prototype;

import static org.fortiss.tooling.base.layout.DefaultLayoutConstants.DEFAULT_SHAPE_MINIMUM_HEIGHT;
import static org.fortiss.tooling.base.layout.DefaultLayoutConstants.DEFAULT_SHAPE_MINIMUM_WIDTH;
import static org.fortiss.tooling.base.ui.utils.LayoutDataUIUtils.setConnectorPosition;
import static org.fortiss.tooling.base.utils.LayoutDataUtils.setNodeBounds;
import static org.fortiss.tooling.base.utils.LayoutDataUtils.setNodePosition;
import static org.fortiss.tooling.base.utils.LayoutModelElementFactory.createRectangle;

import org.fortiss.af3.platform.raspberry.model.ActuatorPWM;
import org.fortiss.af3.platform.raspberry.model.CanBus;
import org.fortiss.af3.platform.raspberry.model.CanConnector;
import org.fortiss.af3.platform.raspberry.model.ConsoleOutput;
import org.fortiss.af3.platform.raspberry.model.RaspberryPi;
import org.fortiss.af3.platform.raspberry.model.brick.AccelerationXSensor;
import org.fortiss.af3.platform.raspberry.model.brick.AccelerationYSensor;
import org.fortiss.af3.platform.raspberry.model.brick.AccelerationZSensor;
import org.fortiss.af3.platform.raspberry.model.brick.ActuatorDigits;
import org.fortiss.af3.platform.raspberry.model.brick.AngularVelocityXSensor;
import org.fortiss.af3.platform.raspberry.model.brick.AngularVelocityYSensor;
import org.fortiss.af3.platform.raspberry.model.brick.AngularVelocityZSensor;
import org.fortiss.af3.platform.raspberry.model.brick.LaserRangeSensor;
import org.fortiss.af3.platform.raspberry.model.brick.UltraSonicSensor;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button1;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button2;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button3;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button4;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonL1;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonL2;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonR1;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonR2;
import org.fortiss.af3.platform.raspberry.model.gamepad.Left_StickX_Position;
import org.fortiss.af3.platform.raspberry.model.gamepad.Left_StickY_Position;
import org.fortiss.af3.platform.raspberry.model.gamepad.Right_StickX_Position;
import org.fortiss.af3.platform.raspberry.model.gamepad.Right_StickY_Position;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonA;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonB;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonHome;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonL3;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonR3;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonSelect;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonStart;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonX;
import org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonY;
import org.fortiss.af3.platform.raspberry.model.rumblepad.DPadDown;
import org.fortiss.af3.platform.raspberry.model.rumblepad.DPadLeft;
import org.fortiss.af3.platform.raspberry.model.rumblepad.DPadRight;
import org.fortiss.af3.platform.raspberry.model.rumblepad.DPadUp;
import org.fortiss.af3.platform.raspberry.model.rumblepad.L2_Position;
import org.fortiss.af3.platform.raspberry.model.rumblepad.R2_Position;
import org.fortiss.af3.platform.raspberry.model.rumblepad.RumbleMagnitudeStrong;
import org.fortiss.af3.platform.raspberry.model.rumblepad.RumbleMagnitudeWeak;
import org.fortiss.af3.platform.raspberry.model.rumblepad.SimpleRumbleFeature;
import org.fortiss.af3.platform.raspberry.util.RaspberryModelElementFactory;
import org.fortiss.tooling.kernel.extension.base.PrototypeProviderBase;
import org.fortiss.tooling.kernel.extension.data.PrototypeCategory;

/**
 * 
 * @author eder
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating RED Hash:
 */
public class ProtoypeProvider extends PrototypeProviderBase {

	/** Stores the category to display for these prototypes. */
	protected final static String CATEGORY_NAME = "RaspberryPI Platform";
	/** Category for gamepad elements. */
	protected final static String GAMEPAD = "Gamepad";
	/** Category for rumblepad elements. */
	protected final static String RUMBLEPAD = "Rumblepad";
	/** Category for brick elements. */
	protected final static String BRICK = "Bricklets";

	/** {@inheritDoc} */
	@Override
	protected void registerPrototypes() {
		RaspberryPi pi = RaspberryModelElementFactory.createRaspberryPi();
		registerPrimaryPrototype("RaspberryPi", pi, CATEGORY_NAME);
		PrototypeCategory prototypeCategory = registerPrototypeCategory(CATEGORY_NAME);
		registerPrototypeCategory(prototypeCategory, GAMEPAD);
		registerPrototypeCategory(prototypeCategory, RUMBLEPAD);
		registerPrototypeCategory(prototypeCategory, BRICK);

		CanBus bus = RaspberryModelElementFactory.createCanBus();
		setNodeBounds(bus,
				createRectangle(0, 0, DEFAULT_SHAPE_MINIMUM_WIDTH, DEFAULT_SHAPE_MINIMUM_HEIGHT));
		registerPrototype("CanBus", bus, CATEGORY_NAME);

		CanConnector con = RaspberryModelElementFactory.createCanConnector();
		setNodePosition(con, 0, 0);
		setConnectorPosition(con, 0, 0);
		registerPrototype("CanConnector", con, CATEGORY_NAME);

		ActuatorPWM pwm = RaspberryModelElementFactory.createActuatorPWM();
		setNodePosition(pwm, 0, 0);
		setConnectorPosition(pwm, 0, 0);
		registerPrototype("PWM_Actuator", pwm, CATEGORY_NAME);

		ConsoleOutput printf = RaspberryModelElementFactory.createConsoleOutput();
		setNodePosition(printf, 0, 0);
		setConnectorPosition(printf, 0, 0);
		registerPrototype("Console_Output", printf, CATEGORY_NAME);

		ActuatorDigits digits = RaspberryModelElementFactory.createActuatorDigits();
		setNodePosition(digits, 0, 0);
		setConnectorPosition(digits, 0, 0);
		registerPrototype("Segment_Digits", digits, BRICK);

		Button1 button1 = RaspberryModelElementFactory.createButton1();
		setNodePosition(button1, 0, 0);
		setConnectorPosition(button1, 0, 0);
		registerPrototype(button1.getName(), button1, GAMEPAD);

		Button2 button2 = RaspberryModelElementFactory.createButton2();
		setNodePosition(button2, 0, 0);
		setConnectorPosition(button2, 0, 0);
		registerPrototype(button2.getName(), button2, GAMEPAD);

		Button3 button3 = RaspberryModelElementFactory.createButton3();
		setNodePosition(button3, 0, 0);
		setConnectorPosition(button3, 0, 0);
		registerPrototype(button3.getName(), button3, GAMEPAD);

		Button4 button4 = RaspberryModelElementFactory.createButton4();
		setNodePosition(button4, 0, 0);
		setConnectorPosition(button4, 0, 0);
		registerPrototype(button4.getName(), button4, GAMEPAD);

		ButtonL1 buttonL1 = RaspberryModelElementFactory.createButtonL1();
		setNodePosition(buttonL1, 0, 0);
		setConnectorPosition(buttonL1, 0, 0);
		registerPrototype(buttonL1.getName(), buttonL1, GAMEPAD);

		ButtonL2 buttonL2 = RaspberryModelElementFactory.createButtonL2();
		setNodePosition(buttonL2, 0, 0);
		setConnectorPosition(buttonL2, 0, 0);
		registerPrototype(buttonL2.getName(), buttonL2, GAMEPAD);

		ButtonR1 buttonR1 = RaspberryModelElementFactory.createButtonR1();
		setNodePosition(buttonR1, 0, 0);
		setConnectorPosition(buttonR1, 0, 0);
		registerPrototype(buttonR1.getName(), buttonR1, GAMEPAD);

		ButtonR2 buttonR2 = RaspberryModelElementFactory.createButtonR2();
		setNodePosition(buttonR2, 0, 0);
		setConnectorPosition(buttonR2, 0, 0);
		registerPrototype(buttonR2.getName(), buttonR2, GAMEPAD);

		Left_StickX_Position Left_StickX = RaspberryModelElementFactory.createLeftStickX();
		setNodePosition(Left_StickX, 0, 0);
		setConnectorPosition(Left_StickX, 0, 0);
		registerPrototype(Left_StickX.getName(), Left_StickX, GAMEPAD);

		Left_StickY_Position Left_StickY = RaspberryModelElementFactory.createLeftStickY();
		setNodePosition(Left_StickY, 0, 0);
		setConnectorPosition(Left_StickY, 0, 0);
		registerPrototype(Left_StickY.getName(), Left_StickY, GAMEPAD);

		Right_StickX_Position Right_StickX = RaspberryModelElementFactory.createRightStickX();
		setNodePosition(Right_StickX, 0, 0);
		setConnectorPosition(Right_StickX, 0, 0);
		registerPrototype(Right_StickX.getName(), Right_StickX, GAMEPAD);

		Right_StickY_Position Right_StickY = RaspberryModelElementFactory.createRightStickY();
		setNodePosition(Right_StickY, 0, 0);
		setConnectorPosition(Right_StickY, 0, 0);
		registerPrototype(Right_StickY.getName(), Right_StickY, GAMEPAD);

		UltraSonicSensor uss = RaspberryModelElementFactory.createUltraSonicSensor();
		setNodePosition(uss, 0, 0);
		setConnectorPosition(uss, 0, 0);
		registerPrototype(uss.getName(), uss, BRICK);

		LaserRangeSensor lsr = RaspberryModelElementFactory.createLaserRangeSensor();
		setNodePosition(lsr, 0, 0);
		setConnectorPosition(lsr, 0, 0);
		registerPrototype(lsr.getName(), lsr, BRICK);

		AccelerationXSensor accX = RaspberryModelElementFactory.createAccelerationXSensor();
		setNodePosition(accX, 0, 0);
		setConnectorPosition(accX, 0, 0);
		registerPrototype(accX.getName(), accX, BRICK);

		AccelerationYSensor accY = RaspberryModelElementFactory.createAccelerationYSensor();
		setNodePosition(accY, 0, 0);
		setConnectorPosition(accY, 0, 0);
		registerPrototype(accY.getName(), accY, BRICK);

		AccelerationZSensor accZ = RaspberryModelElementFactory.createAccelerationZSensor();
		setNodePosition(accZ, 0, 0);
		setConnectorPosition(accZ, 0, 0);
		registerPrototype(accZ.getName(), accZ, BRICK);

		AngularVelocityXSensor avX = RaspberryModelElementFactory.createAngularVelocityXSensor();
		setNodePosition(avX, 0, 0);
		setConnectorPosition(avX, 0, 0);
		registerPrototype(avX.getName(), avX, BRICK);

		AngularVelocityYSensor avY = RaspberryModelElementFactory.createAngularVelocityYSensor();
		setNodePosition(avY, 0, 0);
		setConnectorPosition(avY, 0, 0);
		registerPrototype(avY.getName(), avY, BRICK);

		AngularVelocityZSensor avZ = RaspberryModelElementFactory.createAngularVelocityZSensor();
		setNodePosition(avZ, 0, 0);
		setConnectorPosition(avZ, 0, 0);
		registerPrototype(avZ.getName(), avZ, BRICK);

		org.fortiss.af3.platform.raspberry.model.rumblepad.Left_StickX_Position rplsx =
				RaspberryModelElementFactory.createRumbleLeftStickX();
		setNodePosition(rplsx, 0, 0);
		setConnectorPosition(rplsx, 0, 0);
		registerPrototype(rplsx.getName(), rplsx, RUMBLEPAD);

		org.fortiss.af3.platform.raspberry.model.rumblepad.Left_StickY_Position rplsy =
				RaspberryModelElementFactory.createRumbleLeftStickY();
		setNodePosition(rplsy, 0, 0);
		setConnectorPosition(rplsy, 0, 0);
		registerPrototype(rplsy.getName(), rplsy, RUMBLEPAD);

		org.fortiss.af3.platform.raspberry.model.rumblepad.Right_StickX_Position rprsx =
				RaspberryModelElementFactory.createRumbleRightStickX();
		setNodePosition(rprsx, 0, 0);
		setConnectorPosition(rprsx, 0, 0);
		registerPrototype(rprsx.getName(), rprsx, RUMBLEPAD);

		org.fortiss.af3.platform.raspberry.model.rumblepad.Right_StickY_Position rprsy =
				RaspberryModelElementFactory.createRumbleRightStickY();
		setNodePosition(rprsy, 0, 0);
		setConnectorPosition(rprsy, 0, 0);
		registerPrototype(rprsy.getName(), rprsy, RUMBLEPAD);

		org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonL1 rpl1 =
				RaspberryModelElementFactory.createRumbleButtonL1();
		setNodePosition(rpl1, 0, 0);
		setConnectorPosition(rpl1, 0, 0);
		registerPrototype(rpl1.getName(), rpl1, RUMBLEPAD);

		org.fortiss.af3.platform.raspberry.model.rumblepad.ButtonR1 rpr1 =
				RaspberryModelElementFactory.createRumbleButtonR1();
		setNodePosition(rpr1, 0, 0);
		setConnectorPosition(rpr1, 0, 0);
		registerPrototype(rpr1.getName(), rpr1, RUMBLEPAD);

		L2_Position rpl2 = RaspberryModelElementFactory.createRumbleL2Position();
		setNodePosition(rpl2, 0, 0);
		setConnectorPosition(rpl2, 0, 0);
		registerPrototype(rpl2.getName(), rpl2, RUMBLEPAD);

		R2_Position rpr2 = RaspberryModelElementFactory.createRumbleR2Position();
		setNodePosition(rpr2, 0, 0);
		setConnectorPosition(rpr2, 0, 0);
		registerPrototype(rpr2.getName(), rpr2, RUMBLEPAD);

		ButtonL3 rpl3 = RaspberryModelElementFactory.createRumbleButtonL3();
		setNodePosition(rpl3, 0, 0);
		setConnectorPosition(rpl3, 0, 0);
		registerPrototype(rpl3.getName(), rpl3, RUMBLEPAD);

		ButtonR3 rpr3 = RaspberryModelElementFactory.createRumbleButtonR3();
		setNodePosition(rpr3, 0, 0);
		setConnectorPosition(rpr3, 0, 0);
		registerPrototype(rpr3.getName(), rpr3, RUMBLEPAD);

		DPadUp rpdpu = RaspberryModelElementFactory.createRumbleDPadUp();
		setNodePosition(rpdpu, 0, 0);
		setConnectorPosition(rpdpu, 0, 0);
		registerPrototype(rpdpu.getName(), rpdpu, RUMBLEPAD);

		DPadDown rpdpd = RaspberryModelElementFactory.createRumbleDPadDown();
		setNodePosition(rpdpd, 0, 0);
		setConnectorPosition(rpdpd, 0, 0);
		registerPrototype(rpdpd.getName(), rpdpd, RUMBLEPAD);

		DPadLeft rpdpl = RaspberryModelElementFactory.createRumbleDPadLeft();
		setNodePosition(rpdpl, 0, 0);
		setConnectorPosition(rpdpl, 0, 0);
		registerPrototype(rpdpl.getName(), rpdpl, RUMBLEPAD);

		DPadRight rpdpr = RaspberryModelElementFactory.createRumbleDPadRight();
		setNodePosition(rpdpr, 0, 0);
		setConnectorPosition(rpdpr, 0, 0);
		registerPrototype(rpdpr.getName(), rpdpr, RUMBLEPAD);

		ButtonA rpba = RaspberryModelElementFactory.createRumbleButtonA();
		setNodePosition(rpba, 0, 0);
		setConnectorPosition(rpba, 0, 0);
		registerPrototype(rpba.getName(), rpba, RUMBLEPAD);

		ButtonB rpbb = RaspberryModelElementFactory.createRumbleButtonB();
		setNodePosition(rpbb, 0, 0);
		setConnectorPosition(rpbb, 0, 0);
		registerPrototype(rpbb.getName(), rpbb, RUMBLEPAD);

		ButtonX rpbx = RaspberryModelElementFactory.createRumbleButtonX();
		setNodePosition(rpbx, 0, 0);
		setConnectorPosition(rpbx, 0, 0);
		registerPrototype(rpbx.getName(), rpbx, RUMBLEPAD);

		ButtonY rpby = RaspberryModelElementFactory.createRumbleButtonY();
		setNodePosition(rpby, 0, 0);
		setConnectorPosition(rpby, 0, 0);
		registerPrototype(rpby.getName(), rpby, RUMBLEPAD);

		ButtonStart rpbst = RaspberryModelElementFactory.createRumbleButtonStart();
		setNodePosition(rpbst, 0, 0);
		setConnectorPosition(rpbst, 0, 0);
		registerPrototype(rpbst.getName(), rpbst, RUMBLEPAD);

		ButtonSelect rpbse = RaspberryModelElementFactory.createRumbleButtonSelect();
		setNodePosition(rpbse, 0, 0);
		setConnectorPosition(rpbse, 0, 0);
		registerPrototype(rpbse.getName(), rpbse, RUMBLEPAD);

		ButtonHome rpbh = RaspberryModelElementFactory.createRumbleButtonHome();
		setNodePosition(rpbh, 0, 0);
		setConnectorPosition(rpbh, 0, 0);
		registerPrototype(rpbh.getName(), rpbh, RUMBLEPAD);

		SimpleRumbleFeature srf =
				RaspberryModelElementFactory.createRumbleSimpleRumbleFeaturePosition();
		setNodePosition(srf, 0, 0);
		setConnectorPosition(srf, 0, 0);
		registerPrototype(srf.getName(), srf, RUMBLEPAD);

		RumbleMagnitudeStrong rms = RaspberryModelElementFactory.createRumbleMagnitudeStrong();
		setNodePosition(rms, 0, 0);
		setConnectorPosition(rms, 0, 0);
		registerPrototype(rms.getName(), rms, RUMBLEPAD);

		RumbleMagnitudeWeak rmw = RaspberryModelElementFactory.createRumbleMagnitudeWeak();
		setNodePosition(rmw, 0, 0);
		setConnectorPosition(rmw, 0, 0);
		registerPrototype(rmw.getName(), rmw, RUMBLEPAD);
	}
}
